Converts an rtf document to html, text or latex. Output in html is recommended
because unrtf has limited support for converting between character encodings
which is problematic for non-ascii text.
use a custom dir with .conf files which serve as output templates.
Details
Output can be customized via a set of .conf files which serve as templates for
the various formats. The default conf files are located in system.file("share", package = "unrtf")
To modify the output, copy these files to a custom location and set pass the
directory as the conf_dir argument in unrtf.
# \donttest{library(unrtf)
text <- unrtf("https://jeroen.github.io/files/sample.rtf", format = "text")
html <- unrtf("https://jeroen.github.io/files/sample.rtf", format = "html")
cat(text)
# }